package javax.swing.colorchooser;

import java.awt.Container;
import javax.swing.JComponent;
import javax.swing.JSpinner;
import java.awt.event.ActionEvent;
import java.awt.Insets;
import java.awt.ContainerOrderFocusTraversalPolicy;
import javax.swing.border.EmptyBorder;
import javax.swing.JRadioButton;
import javax.swing.JLabel;
import javax.swing.ButtonGroup;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Color;
import java.awt.event.ActionListener;
import javax.swing.JPanel;

final class ColorPanel extends JPanel implements ActionListener
{
    private final SlidingSpinner[] spinners;
    private final float[] values;
    private final ColorModel model;
    private Color color;
    private int x;
    private int y;
    private int z;
    
    ColorPanel(ColorModel model) {
        super(new GridBagLayout());
        this.spinners = new SlidingSpinner[5];
        this.values = new float[this.spinners.length];
        this.x = 1;
        this.y = 2;
        GridBagConstraints gridBagConstraints = new GridBagConstraints();
        gridBagConstraints.fill = 2;
        gridBagConstraints.gridx = 1;
        ButtonGroup buttonGroup = new ButtonGroup();
        Object border = null;
        for (int i = 0; i < this.spinners.length; ++i) {
            if (i < 3) {
                JRadioButton o = new JRadioButton();
                if (i == 0) {
                    Insets insets = o.getInsets();
                    insets.left = o.getPreferredSize().width;
                    border = new EmptyBorder(insets);
                    o.setSelected(true);
                    gridBagConstraints.insets.top = 5;
                }
                this.add(o, gridBagConstraints);
                buttonGroup.add(o);
                o.setActionCommand(Integer.toString(i));
                o.addActionListener(this);
                this.spinners[i] = new SlidingSpinner(this, o);
            }
            else {
                JLabel comp = new JLabel();
                this.add(comp, gridBagConstraints);
                comp.setBorder(border);
                comp.setFocusable(false);
                this.spinners[i] = new SlidingSpinner(this, comp);
            }
        }
        gridBagConstraints.gridx = 2;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets.top = 0;
        gridBagConstraints.insets.left = 5;
        SlidingSpinner[] spinners = this.spinners;
        for (int length = spinners.length, j = 0; j < length; gridBagConstraints.insets.top = 5, ++j) {
            this.add(spinners[j].getSlider(), gridBagConstraints);
        }
        gridBagConstraints.gridx = 3;
        gridBagConstraints.weightx = 0.0;
        gridBagConstraints.insets.top = 0;
        SlidingSpinner[] spinners2 = this.spinners;
        for (int length2 = spinners2.length, k = 0; k < length2; gridBagConstraints.insets.top = 5, ++k) {
            this.add(spinners2[k].getSpinner(), gridBagConstraints);
        }
        this.setFocusTraversalPolicy(new ContainerOrderFocusTraversalPolicy());
        this.setFocusTraversalPolicyProvider(true);
        this.setFocusable(false);
        this.model = model;
    }
    
    @Override
    public void actionPerformed(ActionEvent actionEvent) {
        try {
            this.z = Integer.parseInt(actionEvent.getActionCommand());
            this.y = ((this.z != 2) ? 2 : 1);
            this.x = (this.z == 0);
            this.getParent().repaint();
        }
        catch (NumberFormatException ex) {}
    }
    
    void buildPanel() {
        int count = this.model.getCount();
        this.spinners[4].setVisible(count > 4);
        for (int i = 0; i < count; ++i) {
            String label = this.model.getLabel(this, i);
            JComponent label2 = this.spinners[i].getLabel();
            if ((label2 instanceof JRadioButton)) {
                JRadioButton radioButton = (JRadioButton)label2;
                radioButton.setText(label);
                radioButton.getAccessibleContext().setAccessibleDescription(label);
            }
            else if ((label2 instanceof JLabel)) {
                ((JLabel)label2).setText(label);
            }
            this.spinners[i].setRange(this.model.getMinimum(i), this.model.getMaximum(i));
            this.spinners[i].setValue(this.values[i]);
            this.spinners[i].getSlider().getAccessibleContext().setAccessibleName(label);
            this.spinners[i].getSpinner().getAccessibleContext().setAccessibleName(label);
            JSpinner.DefaultEditor defaultEditor = (JSpinner.DefaultEditor)this.spinners[i].getSpinner().getEditor();
            defaultEditor.getTextField().getAccessibleContext().setAccessibleName(label);
            this.spinners[i].getSlider().getAccessibleContext().setAccessibleDescription(label);
            this.spinners[i].getSpinner().getAccessibleContext().setAccessibleDescription(label);
            defaultEditor.getTextField().getAccessibleContext().setAccessibleDescription(label);
        }
    }
    
    void colorChanged() {
        this.color = new Color(this.getColor(0), true);
        Container parent = this.getParent();
        if ((parent instanceof ColorChooserPanel)) {
            ColorChooserPanel colorChooserPanel = (ColorChooserPanel)parent;
            colorChooserPanel.setSelectedColor(this.color);
            colorChooserPanel.repaint();
        }
    }
    
    float getValueX() {
        return this.spinners[this.x].getValue();
    }
    
    float getValueY() {
        return 1.0f - this.spinners[this.y].getValue();
    }
    
    float getValueZ() {
        return 1.0f - this.spinners[this.z].getValue();
    }
    
    void setValue(float n) {
        this.spinners[this.z].setValue(1.0f - n);
        this.colorChanged();
    }
    
    void setValue(float value, float n) {
        this.spinners[this.x].setValue(value);
        this.spinners[this.y].setValue(1.0f - n);
        this.colorChanged();
    }
    
    int getColor(float n) {
        this.setDefaultValue(this.x);
        this.setDefaultValue(this.y);
        this.values[this.z] = 1.0f - n;
        return this.getColor(3);
    }
    
    int getColor(float n, float n2) {
        this.values[this.x] = n;
        this.values[this.y] = 1.0f - n2;
        this.setValue(this.z);
        return this.getColor(3);
    }
    
    void setColor(Color color) {
        if (!color.equals(this.color)) {
            this.color = color;
            this.model.setColor(color.getRGB(), this.values);
            for (int i = 0; i < this.model.getCount(); ++i) {
                this.spinners[i].setValue(this.values[i]);
            }
        }
    }
    
    private int getColor(int i) {
        while (i < this.model.getCount()) {
            this.setValue(i++);
        }
        return this.model.getColor(this.values);
    }
    
    private void setValue(int n) {
        this.values[n] = this.spinners[n].getValue();
    }
    
    private void setDefaultValue(int n) {
        float default1 = this.model.getDefault(n);
        this.values[n] = ((default1 < 0.0f) ? this.spinners[n].getValue() : default1);
    }
}
